@@ -5,4 +5,8 @@ def return_filename(url):
 
 def return_filename_without_format(filename):
 	file = filename.split('.')
-	return file[0]
\ No newline at end of file
+	return file[0]
+
+def return_format(filename):
+	format = filename.split('.')
+	return format[1]
\ No newline at end of file
